package
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Mar 30, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Class[A, B, C any, MF M[func(A) B], MA M[A], MB M[B], MC M[C]] interface {
applicative.Class[A, B, C, MF, MA, MB, MC]
Bind(MA, func(A) MB) MB
Then(MA, MB) MB
Return(A) MA
}
type M[T any] interface{}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.