package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Apr 6, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type InL[F, G, A any] struct {
Fn F
Value A
}
InL is the left side summation.
func (il InL[F, G, A]) DValue() Sum[F, G, A]
type InR[F, G, A any] struct {
Fn G
Value A
}
InR is the right side summation.
func (ir InR[F, G, A]) DValue() Sum[F, G, A]
Sum is the sum type for Sum.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.