package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Mar 30, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Class[A any] interface {
semigroup.Class[A]
MEmpty() A
MAppend(x, y A) A
MConcat([]A) A
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.