package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Mar 30, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Type[A any, L []A] struct{}
func NewType[A any, L []A]() Type[A, L]
func (t Type[A, L]) MAppend(x, y L) L
func (t Type[A, L]) MConcat(xs []L) L
func (t Type[A, L]) MEmpty() L
func (t Type[A, L]) SAssoc(x, y L) L
Source Files
¶
Click to show internal directories.
Click to hide internal directories.